xd
==

A list of handy commands which makes life easier.


Install
-------

::

    pip install xd -U
    # pip install git+https://github.com/damnever/xd.git@master -U


Usage
-----

::

   Usage: xd [OPTIONS] COMMAND [ARGS]...

     A list of handy commands which makes life easier.

   Options:
     --help  Show this message and exit.

   Commands:
     batch    Execute a program multiple times in parallel.
     config   Manipulate config files: json, yaml, ini and toml.
     gitinit  Init a git project, or creates a LICENSE/.gitignore file.
     version  Show version.
     watch    Execute a program periodically.


::

    xd --help
    xd <subcommand> --help
